@@ -7,3 +7,6 @@ from .timing import get_now
 from .containers import deep_get, Simple_Child, Proper_Child
 from .logic import sort_by, resolve_order, toposort
 
+
+__author__ = 'Felix Leeb'
+__version__ = '0.1.1'
